==> distfun-0.3-1-src.zip: distfun/sci_gateway/cgrand/sci_distfun_grandchi.c <==

/*
* Copyright (C)  2012 - Michael Baudin
* Copyright (C)  2001 - Bruno Pincon
* Copyright (C) ENPC
*
* This file must be used under the terms of the CeCILL.
* This source file is licensed as described in the file COPYING, which
* you should have received as part of this distribution.  The terms
* are also available at
* http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
*
*/

/*------------------------------------------------------------------------
*    Interface for grand
*    jpc@cermics.enpc.fr
*    stuff to deal with several generators added
*         by Bruno Pincon (12/11/2001)
*
--------------------------------------------------------------------------*/
#include <string.h>
#include <math.h>

// From Distfun:
#include "gwsupport.h"
#include "genrand.h"
#include "gw_distfungrand.h"
#include "gw_distfungrand_support.h" 

// From Scilab:
#include "api_scilab.h"
#include "stack-c.h"

/**************************************************
Y=distfun_grandchi(m,n,Df) 

generates random variates from the chisquare distribution 
with Df (real > 0.0) degrees of freedom. 

Related function(s) : cdfchi.
***********************************************************************/

int sci_distfun_grandchi(char *fname,unsigned long fname_len)
{
	int rRows,rCols;
	int readFlag;
	int ma, na;

	double * pa = NULL;

	CheckRhs(3,3);
	CheckLhs(1,1);

	// Get Arg #1 = M, Arg #2 = N
	readFlag = distfun_GetMN ( fname , &rRows , &rCols );
	if ( readFlag == 0)
	{ 
		return 0;
	}
    // Arg #3 : df
	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, 3, &pa, &ma, &na);
	if ( readFlag == 0)
	{ 
		return 0;
	}
	readFlag = gwsupport_CheckDoubleMatrixGreaterOrEqual (fname, 3, pa, ma, na, 0.0);
	if ( readFlag == 0)
	{ 
		return 0;
	}
    // Compute the result (if necessary, expand the argument df)
	readFlag = distfun_computeRandgenA (fname, ma, na, pa, rRows, rCols, C2F(genchi));
	if ( readFlag == 0)
	{ 
		return 0;
	}
	LhsVar(1) = Rhs+1;

	return 0;
}

==> distfun-0.5-1-src.zip: distfun/sci_gateway/cgrand/sci_distfun_grandchi.c <==

/*
* Copyright (C)  2012 - Michael Baudin
* Copyright (C)  2001 - Bruno Pincon
* Copyright (C) ENPC
*
* This file must be used under the terms of the CeCILL.
* This source file is licensed as described in the file COPYING, which
* you should have received as part of this distribution.  The terms
* are also available at
* http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
*
*/

/*------------------------------------------------------------------------
*    Interface for grand
*    jpc@cermics.enpc.fr
*    stuff to deal with several generators added
*         by Bruno Pincon (12/11/2001)
*
--------------------------------------------------------------------------*/
#include <string.h>
#include <math.h>

// From Distfun:
#include "gwsupport.h"
#include "genrand.h"
#include "gw_distfungrand.h"
#include "gw_distfungrand_support.h" 

// From Scilab:
#include "api_scilab.h"
#include "stack-c.h"

/**************************************************
Y=distfun_grandchi(m,n,Df) 

generates random variates from the chisquare distribution 
with Df (real > 0.0) degrees of freedom. 

Related function(s) : cdfchi.
***********************************************************************/

int sci_distfun_grandchi(char *fname,unsigned long fname_len)
{
	int rRows,rCols;
	int readFlag;
	int ma, na;

	double * pa = NULL;

	CheckInputArgument(pvApiCtx,3,3);
	CheckOutputArgument(pvApiCtx,1,1);

	// Get Arg #1 = M, Arg #2 = N
	readFlag = distfun_GetMN ( fname , &rRows , &rCols );
	if ( readFlag == GWSUPPORT_ERROR)
	{ 
		return 0;
	}
    // Arg #3 : df
	readFlag = gwsupport_GetRealMatrixOfDoubles( fname, 3, &pa, &ma, &na);
	if ( readFlag == GWSUPPORT_ERROR)
	{ 
		return 0;
	}
	readFlag = gwsupport_CheckDoubleMatrixGreaterOrEqual (fname, 3, pa, ma, na, 0.0);
	if ( readFlag == GWSUPPORT_ERROR)
	{ 
		return 0;
	}
    // Compute the result (if necessary, expand the argument df)
	readFlag = distfun_computeRandgenA (fname, ma, na, pa, rRows, rCols, genrand_genchi);
	if ( readFlag == GWSUPPORT_ERROR)
	{ 
		return 0;
	}
	LhsVar(1) = Rhs+1;

	return 0;
}
